From 9b26dfec80017d23c1a2322c91798c53fac4786b Mon Sep 17 00:00:00 2001
From: apfelmaennchen
Date: Sun, 11 Jan 2009 22:50:53 +0000
Subject: [PATCH] small fix to correct encoding of xml output
git-svn-id: https://svn.berlios.de/svnroot/repos/yacy/trunk@5473 6c8d7289-2bf4-0310-a012-ef5d649a1542
---
htroot/xml/bookmarks/get_bookmarks.java | 16 +++++++++++-----
htroot/xml/bookmarks/get_bookmarks.json | 6 +++---
htroot/xml/bookmarks/get_bookmarks.xml | 14 +++++++-------
3 files changed, 21 insertions(+), 15 deletions(-)
diff --git a/htroot/xml/bookmarks/get_bookmarks.json b/htroot/xml/bookmarks/get_bookmarks.json
index 9b2123a1e..b535f1723 100644
--- a/htroot/xml/bookmarks/get_bookmarks.json
+++ b/htroot/xml/bookmarks/get_bookmarks.json
@@ -17,9 +17,9 @@ rows: [
{id:"#[id]#",cell:[
"#[hash]#",
#(public)#"
"::"
"#(/public)#,
-"#[title-enc]#
#[desc-enc]#
#[link]#",
-"
#[tags-enc]#
",
-"#[folders-enc]#
",
+"#[title-html]#
#[desc-html]#
#[link]#",
+"
#[tags-html]#
",
+"#[folders-html]#
",
"#[rfc822date]#
"]}#[comma]#
#{/bookmarks}#
]
diff --git a/htroot/xml/bookmarks/get_bookmarks.xml b/htroot/xml/bookmarks/get_bookmarks.xml
index 52d9baf97..526529740 100644
--- a/htroot/xml/bookmarks/get_bookmarks.xml
+++ b/htroot/xml/bookmarks/get_bookmarks.xml
@@ -3,7 +3,7 @@
#{bookmarks}#
-
+
#{/bookmarks}#
::
@@ -15,9 +15,9 @@
|
#(public)#]]> | ::
]]> | #(/public)#
- #[title-enc]# #[desc-enc]# #[link]#]]> |
- #[tags-enc]# |
]]>
- #[folders-enc]#]]> |
+ #[title-html]# #[desc-html]# #[link]#]]> |
+ #[tags-html]#]]> |
+ #[folders-html]#]]> |
#[rfc822date]#]]> |
#{/bookmarks}#
@@ -41,12 +41,12 @@
#{bookmarks}#-
-
+
#[link]#
#[rfc822date]#
#[hash]#
- #[desc]#]]>
-
+ #[desc-xml]#]]>
+
#{/bookmarks}#
#(/display)#
diff --git a/htroot/xml/bookmarks/get_bookmarks.java b/htroot/xml/bookmarks/get_bookmarks.java
index 13a9743fe..47cf9cbce 100644
--- a/htroot/xml/bookmarks/get_bookmarks.java
+++ b/htroot/xml/bookmarks/get_bookmarks.java
@@ -163,11 +163,17 @@ public class get_bookmarks {
prop.put("display_bookmarks_"+count+"_hash", bookmark.getUrlHash());
prop.put("display_bookmarks_"+count+"_comma", ",");
- // offer both HTML encoded
- prop.putHTML("display_bookmarks_"+count+"_title-enc", bookmark.getTitle());
- prop.putHTML("display_bookmarks_"+count+"_desc-enc", bookmark.getDescription());
- prop.putHTML("display_bookmarks_"+count+"_tags-enc", bookmark.getTagsString().replaceAll(",", ", "));
- prop.putHTML("display_bookmarks_"+count+"_folders-enc", (bookmark.getFoldersString()));
+ // offer HTML encoded
+ prop.putHTML("display_bookmarks_"+count+"_title-html", bookmark.getTitle());
+ prop.putHTML("display_bookmarks_"+count+"_desc-html", bookmark.getDescription());
+ prop.putHTML("display_bookmarks_"+count+"_tags-html", bookmark.getTagsString().replaceAll(",", ", "));
+ prop.putHTML("display_bookmarks_"+count+"_folders-html", (bookmark.getFoldersString()));
+
+ // XML encoded
+ prop.putXML("display_bookmarks_"+count+"_title-xml", bookmark.getTitle());
+ prop.putXML("display_bookmarks_"+count+"_desc-xml", bookmark.getDescription());
+ prop.putXML("display_bookmarks_"+count+"_tags-xml", bookmark.getTagsString());
+ prop.putXML("display_bookmarks_"+count+"_folders-xml", (bookmark.getFoldersString()));
// and plain text (potentially unsecure)
prop.put("display_bookmarks_"+count+"_title", bookmark.getTitle());